┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/panels/places
diff options
context:
space:
mode:
Diffstat (limited to 'src/panels/places')
-rw-r--r--src/panels/places/placesitem.cpp18
-rw-r--r--src/panels/places/placesitem.h2
-rw-r--r--src/panels/places/placesitemmodel.cpp38
-rw-r--r--src/panels/places/placespanel.cpp2
4 files changed, 32 insertions, 28 deletions
diff --git a/src/panels/places/placesitem.cpp b/src/panels/places/placesitem.cpp
index 539b9263d..173da29c5 100644
--- a/src/panels/places/placesitem.cpp
+++ b/src/panels/places/placesitem.cpp
@@ -144,20 +144,20 @@ void PlacesItem::setBookmark(const KBookmark& bookmark)
const GroupType type = groupType();
if (icon().isEmpty()) {
switch (type) {
- case RecentlyAccessedType: setIcon("chronometer"); break;
- case SearchForType: setIcon("nepomuk"); break;
+ case RecentlySavedType: setIcon("chronometer"); break;
+ case SearchForType: setIcon("nepomuk"); break;
case PlacesType:
- default: setIcon("folder");
+ default: setIcon("folder");
}
}
switch (type) {
- case PlacesType: setGroup(i18nc("@item", "Places")); break;
- case RecentlyAccessedType: setGroup(i18nc("@item", "Recently Accessed")); break;
- case SearchForType: setGroup(i18nc("@item", "Search For")); break;
- case DevicesType: setGroup(i18nc("@item", "Devices")); break;
- default: Q_ASSERT(false); break;
+ case PlacesType: setGroup(i18nc("@item", "Places")); break;
+ case RecentlySavedType: setGroup(i18nc("@item", "Recently Saved")); break;
+ case SearchForType: setGroup(i18nc("@item", "Search For")); break;
+ case DevicesType: setGroup(i18nc("@item", "Devices")); break;
+ default: Q_ASSERT(false); break;
}
setHidden(bookmark.metaDataItem("IsHidden") == QLatin1String("true"));
@@ -173,7 +173,7 @@ PlacesItem::GroupType PlacesItem::groupType() const
if (udi().isEmpty()) {
const QString protocol = url().protocol();
if (protocol == QLatin1String("timeline")) {
- return RecentlyAccessedType;
+ return RecentlySavedType;
}
if (protocol.contains(QLatin1String("search"))) {
diff --git a/src/panels/places/placesitem.h b/src/panels/places/placesitem.h
index 297f12d91..4c636ec63 100644
--- a/src/panels/places/placesitem.h
+++ b/src/panels/places/placesitem.h
@@ -44,7 +44,7 @@ public:
{
PlacesType,
SearchForType,
- RecentlyAccessedType,
+ RecentlySavedType,
DevicesType
};
diff --git a/src/panels/places/placespanel.cpp b/src/panels/places/placespanel.cpp
index f19fa1e25..720e07ce3 100644
--- a/src/panels/places/placespanel.cpp
+++ b/src/panels/places/placespanel.cpp
@@ -335,7 +335,7 @@ void PlacesPanel::slotItemDropEvent(int index, QGraphicsSceneDragDropEvent* even
const PlacesItem* destItem = m_model->placesItem(index);
const PlacesItem::GroupType group = destItem->groupType();
- if (group == PlacesItem::SearchForType || group == PlacesItem::RecentlyAccessedType) {
+ if (group == PlacesItem::SearchForType || group == PlacesItem::RecentlySavedType) {
return;
}
diff --git a/src/panels/places/placesitemmodel.cpp b/src/panels/places/placesitemmodel.cpp
index 2ac216958..6accdc837 100644
--- a/src/panels/places/placesitemmodel.cpp
+++ b/src/panels/places/placesitemmodel.cpp
@@ -58,7 +58,7 @@
namespace {
// As long as KFilePlacesView from kdelibs is available in parallel, the
// system-bookmarks for "Recently Accessed" and "Search For" should be
// shown only inside the Places Panel. This is necessary as the stored
// URLs needs to get translated to a Baloo-search-URL on-the-fly to
// be independent from changes in the Baloo-search-URL-syntax.
@@ -313,7 +313,8 @@ void PlacesItemModel::requestEject(int index)
Solid::OpticalDrive* drive = item->device().parent().as<Solid::OpticalDrive>();
if (drive) {
connect(drive, SIGNAL(ejectDone(Solid::ErrorType,QVariant,QString)),
- this, SLOT(slotStorageTeardownDone(Solid::ErrorType,QVariant)));
+ this, SLOT(slotStorageTeardownDone(Solid::ErrorType,QVariant)),
+ Qt::UniqueConnection);
drive->eject();
} else {
const QString label = item->text();
@@ -330,7 +331,8 @@ void PlacesItemModel::requestTeardown(int index)
Solid::StorageAccess* access = item->device().as<Solid::StorageAccess>();
if (access) {
connect(access, SIGNAL(teardownDone(Solid::ErrorType,QVariant,QString)),
- this, SLOT(slotStorageTeardownDone(Solid::ErrorType,QVariant)));
+ this, SLOT(slotStorageTeardownDone(Solid::ErrorType,QVariant)),
+ Qt::UniqueConnection);
access->teardown();
}
}
@@ -359,7 +361,8 @@ void PlacesItemModel::requestStorageSetup(int index)
m_storageSetupInProgress[access] = index;
connect(access, SIGNAL(setupDone(Solid::ErrorType,QVariant,QString)),
- this, SLOT(slotStorageSetupDone(Solid::ErrorType,QVariant,QString)));
+ this, SLOT(slotStorageSetupDone(Solid::ErrorType,QVariant,QString)),
+ Qt::UniqueConnection);
access->setup();
}
@@ -599,6 +602,7 @@ void PlacesItemModel::slotStorageSetupDone(Solid::ErrorType error,
{
Q_UNUSED(udi);
+ Q_ASSERT(!m_storageSetupInProgress.isEmpty());
const int index = m_storageSetupInProgress.take(sender());
const PlacesItem* item = placesItem(index);
if (!item) {
@@ -738,7 +742,7 @@ void PlacesItemModel::loadBookmarks()
// items should always be collected in one group so the items are collected first
// in separate lists before inserting them.
QList<PlacesItem*> placesItems;
- QList<PlacesItem*> recentlyAccessedItems;
+ QList<PlacesItem*> recentlySavedItems;
QList<PlacesItem*> searchForItems;
QList<PlacesItem*> devicesItems;
@@ -763,11 +767,11 @@ void PlacesItemModel::loadBookmarks()
}
switch (item->groupType()) {
- case PlacesItem::PlacesType: placesItems.append(item); break;
- case PlacesItem::RecentlyAccessedType: recentlyAccessedItems.append(item); break;
- case PlacesItem::SearchForType: searchForItems.append(item); break;
+ case PlacesItem::PlacesType: placesItems.append(item); break;
+ case PlacesItem::RecentlySavedType: recentlySavedItems.append(item); break;
+ case PlacesItem::SearchForType: searchForItems.append(item); break;
case PlacesItem::DevicesType:
- default: Q_ASSERT(false); break;
+ default: Q_ASSERT(false); break;
}
}
}
@@ -782,11 +786,11 @@ void PlacesItemModel::loadBookmarks()
if (missingSystemBookmarks.contains(data.url)) {
PlacesItem* item = createSystemPlacesItem(data);
switch (item->groupType()) {
- case PlacesItem::PlacesType: placesItems.append(item); break;
- case PlacesItem::RecentlyAccessedType: recentlyAccessedItems.append(item); break;
- case PlacesItem::SearchForType: searchForItems.append(item); break;
+ case PlacesItem::PlacesType: placesItems.append(item); break;
+ case PlacesItem::RecentlySavedType: recentlySavedItems.append(item); break;
+ case PlacesItem::SearchForType: searchForItems.append(item); break;
case PlacesItem::DevicesType:
- default: Q_ASSERT(false); break;
+ default: Q_ASSERT(false); break;
}
}
}
@@ -800,7 +804,7 @@ void PlacesItemModel::loadBookmarks()
QList<PlacesItem*> items;
items.append(placesItems);
- items.append(recentlyAccessedItems);
+ items.append(recentlySavedItems);
items.append(searchForItems);
items.append(devicesItems);
@@ -845,7 +849,7 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
const QString protocol = data.url.protocol();
if (protocol == QLatin1String("timeline") || protocol == QLatin1String("search")) {
// As long as the KFilePlacesView from kdelibs is available, the system-bookmarks
// for "Recently Accessed" and "Search For" should be a setting available only
// in the Places Panel (see description of AppNamePrefix for more details).
const QString appName = KGlobal::mainComponent().componentName() + AppNamePrefix;
bookmark.setMetaDataItem("OnlyInApp", appName);
@@ -854,11 +858,11 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
PlacesItem* item = new PlacesItem(bookmark);
item->setSystemItem(true);
// Create default view-properties for all "Search For" and "Recently Accessed" bookmarks
// in case if the user has not already created custom view-properties for a corresponding
// query yet.
const bool createDefaultViewProperties = (item->groupType() == PlacesItem::SearchForType ||
- item->groupType() == PlacesItem::RecentlyAccessedType) &&
+ item->groupType() == PlacesItem::RecentlySavedType) &&
!GeneralSettings::self()->globalViewProps();
if (createDefaultViewProperties) {
ViewProperties props(convertedUrl(data.url));
@@ -58,7 +58,7 @@
namespace {
// As long as KFilePlacesView from kdelibs is available in parallel, the
- // system-bookmarks for "Recently Accessed" and "Search For" should be
+ // system-bookmarks for "Recently Saved" and "Search For" should be
// shown only inside the Places Panel. This is necessary as the stored
// URLs needs to get translated to a Baloo-search-URL on-the-fly to
@@ -845,7 +849,7 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
if (protocol == QLatin1String("timeline") || protocol == QLatin1String("search")) {
// As long as the KFilePlacesView from kdelibs is available, the system-bookmarks
- // for "Recently Accessed" and "Search For" should be a setting available only
+ // for "Recently Saved" and "Search For" should be a setting available only
// in the Places Panel (see description of AppNamePrefix for more details).
const QString appName = KGlobal::mainComponent().componentName() + AppNamePrefix;
@@ -854,11 +858,11 @@ PlacesItem* PlacesItemModel::createSystemPlacesItem(const SystemBookmarkData& da
PlacesItem* item = new PlacesItem(bookmark);
item->setSystemItem(true);
- // Create default view-properties for all "Search For" and "Recently Accessed" bookmarks
+ // Create default view-properties for all "Search For" and "Recently Saved" bookmarks
// in case if the user has not already created custom view-properties for a corresponding
// query yet.